@@ -135,6 +135,10 @@ class Post(Resource):
     def mime(self) -> str:
         return self._generic_getter("mimeType")
 
+    @property
+    def checksum(self):
+        return self._generic_getter("checksum")
+
     @property
     def width(self) -> int:
         return self._generic_getter("canvasWidth")
